sparql Package
==============

:mod:`sparql` Package
---------------------

.. automodule:: rdflib.plugins.sparql
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`aggregates` Module
------------------------

.. automodule:: rdflib.plugins.sparql.aggregates
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`algebra` Module
---------------------

.. automodule:: rdflib.plugins.sparql.algebra
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`compat` Module
--------------------

.. automodule:: rdflib.plugins.sparql.compat
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`datatypes` Module
-----------------------

.. automodule:: rdflib.plugins.sparql.datatypes
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`evaluate` Module
----------------------

.. automodule:: rdflib.plugins.sparql.evaluate
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`evalutils` Module
-----------------------

.. automodule:: rdflib.plugins.sparql.evalutils
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`operators` Module
-----------------------

.. automodule:: rdflib.plugins.sparql.operators
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`parser` Module
--------------------

.. automodule:: rdflib.plugins.sparql.parser
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`parserutils` Module
-------------------------

.. automodule:: rdflib.plugins.sparql.parserutils
    :members:
    :undoc-members:
    :show-inheritance:
    :exclude-members: __dict__,__weakref__

:mod:`processor` Module
-----------------------

.. automodule:: rdflib.plugins.sparql.processor
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`sparql` Module
--------------------

.. automodule:: rdflib.plugins.sparql.sparql
    :members:
    :undoc-members:
    :show-inheritance:
    :exclude-members: __dict__,__weakref__

:mod:`update` Module
--------------------

.. automodule:: rdflib.plugins.sparql.update
    :members:
    :undoc-members:
    :show-inheritance:

Subpackages
-----------

.. toctree::

    rdflib.plugins.sparql.results

